#
# spec file for package ocaml-lablgtk2
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%bcond_with    ocaml_lablgtk2_gl
%bcond_with    ocaml_lablgtk2_glade
%bcond_with    ocaml_lablgtk2_gnomecanvas
%bcond_with    ocaml_lablgtk2_gtksourceview2
%bcond_with    ocaml_lablgtk2_gtkspell
%bcond_without ocaml_lablgtk2_rsvg
# handle built-in ocaml helper from rpm-build, and helper from ocaml-rpm-macros
%global __suseocaml_requires_opts -i GtkSourceView2_types
%global __ocaml_requires_opts -i GtkSourceView2_types

Name:           ocaml-lablgtk2
Version:        2.18.11
Release:        bp156.3.4
%{?ocaml_preserve_bytecode}
Summary:        An Objective Caml Interface to gtk2+
License:        LGPL-2.1-only
Group:          Development/Languages/OCaml
BuildRoot:      %_tmppath/%name-%version-build
URL:            https://opam.ocaml.org/packages/lablgtk
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  ocaml
BuildRequires:  ocaml-rpm-macros >= 20210409
BuildRequires:  ocamlfind(findlib)
%if %{with ocaml_lablgtk2_gl}
BuildRequires:  ocamlfind(lablgl)
%endif
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(gtk+-2.0)
%if %{with ocaml_lablgtk2_gtksourceview2}
BuildRequires:  pkgconfig(gtksourceview-2.0)
%endif
%if %{with ocaml_lablgtk2_gtkspell}
BuildRequires:  pkgconfig(gtkspell-2.0)
%endif
%if %{with ocaml_lablgtk2_glade}
BuildRequires:  pkgconfig(libglade-2.0)
%endif
%if %{with ocaml_lablgtk2_gnomecanvas}
BuildRequires:  pkgconfig(libgnomecanvas-2.0)
%endif
%if %{with ocaml_lablgtk2_rsvg}
BuildRequires:  pkgconfig(librsvg-2.0)
%endif

Provides:       lablgtk2 = %{version}
Obsoletes:      lablgtk2 < %{version}
Provides:       ocaml-lablgtk = %{version}
Obsoletes:      ocaml-lablgtk < %{version}

%description
LablGTK2 uses the rich type system of Objective Caml 3 to provide a
strongly typed, yet very comfortable, object-oriented interface to
GTK2+. Objective Caml threads are supported, including for the top
level, which allows the interactive use of the library.


%package devel
Summary:        An Objective Caml interface to gtk2+
Group:          Development/Languages/OCaml
Provides:       lablgtk2-devel = %{version}
Obsoletes:      lablgtk2-devel < %{version}
Provides:       ocaml-lablgtk-devel = %{version}
Obsoletes:      ocaml-lablgtk-devel < %{version}
Provides:       lablgtk2:/usr/lib/ocaml/lablgtk2/glib.cmi
Requires:       %{name} = %{version}
Requires:       pkgconfig(gtk+-2.0)
%if %{with ocaml_lablgtk2_rsvg}
Requires:       pkgconfig(librsvg-2.0)
%endif

%description devel
LablGTK2 uses the rich type system of Objective Caml 3 to provide a
strongly typed, yet very comfortable, object-oriented interface to
GTK2+. Objective Caml threads are supported, including for the top
level, which allows for interactive use of the library.

%prep
%setup -q

%build
chmod a-x README
%configure \
	--without-gl \
	--without-glade \
	--without-gnomecanvas \
	--without-gnomeui \
	--without-gtksourceview \
	--without-gtksourceview2 \
	--without-gtkspell \
	--without-panel \
	--without-quartz \
	--without-rsvg \
	\
%if %{with ocaml_lablgtk2_gl}
	--with-gl \
%endif
%if %{with ocaml_lablgtk2_glade}
	--with-glade \
%endif
%if %{with ocaml_lablgtk2_gnomecanvas}
	--with-gnomecanvas \
%endif
%if %{with ocaml_lablgtk2_gtksourceview2}
	--with-gtksourceview2 \
%endif
%if %{with ocaml_lablgtk2_gtkspell}
	--with-gtkspell \
%endif
%if %{with ocaml_lablgtk2_rsvg}
	--with-rsvg \
%endif
	%{nil}
make world
make opt

%install
%make_install
# Remove ld.conf (part of main OCaml dist).
rm -fv %{buildroot}%{ocaml_standard_library}/ld.conf
#
%ocaml_create_file_list

%files -f %{name}.files
%defattr(-,root,root,-)
%doc README
%{_bindir}/*

%files devel -f %{name}.files.devel
%defattr(-,root,root,-)
%{ocaml_standard_library}/*/propcc
%{ocaml_standard_library}/*/varcc

%changelog
* Sat Dec 18 2021 ohering@suse.de
- Require gtk2 and rsvg in the devel pacakge
  The built-in build.ml contains the output of pkgconfig --libs
* Fri Apr  9 2021 ohering@suse.de
- Update to version 2.18.11
  Remove obsolete ocaml-lablgtk2.ml_table_extension_events.patch
- add build conditionals for gl,glade,gnomecanvas,gtksourceview2,
  gtkspell and rsvg, enable only the latter be default
- Remove ocaml_native_compiler conditional
  build native target unconditionally
* Wed Jun 17 2020 ohering@suse.de
- Fix gcc10 build with ocaml-lablgtk2.ml_table_extension_events.patch
* Thu May 14 2020 ohering@suse.de
- The filename for rpm *.attr files and the tag used within these
  files must match. Otherwise rpm will not execute the helper scripts.
  Use helper 'suseocaml' in addition to 'ocaml' to avoid
  filename conflicts with rpm-build.rpm (bsc#1154874)
* Thu Feb 20 2020 ohering@suse.de
- Require current ocaml-rpm-macros
- Remove bogus Requires/Provides override
* Thu Jan 30 2020 ohering@suse.de
- Update to version 2.18.10.
  prepare for ocaml-4.10
* Fri Nov  1 2019 ohering@suse.de
- Require current rpm macros
- Use _service file
* Wed Oct 30 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2.18.6.
  * finish transition for applications subdirectory.
  * prepare for 4.06: -safe-string transition and warnings.
- Update to version 2.18.7.
  * Support property "expand" of GtkTreeViewColumn.
  * ensure we compile on ocaml 4.05.
  * put examples explicitly in the public domain.
  * In GToolbox, add support for declaring dialogs transient for a
    parent.
  * Add some properties to GText.tag
  * Add require for threads in META
- Update to version 2.18.8.
  * remove -warn-error to allow compilation on future versions of
    ocaml
  * mark Gdk.PointArray.t and Gdk.SegmentArray.t as [@@ boxed]
- Change License to LGPL-2.1-only, as indicated by file headers.
- Remove non-free applications subdirectory.
* Fri May 18 2018 bjorn.lie@gmail.com
- Drop optional libgnomeui-devel BuildRequires.
* Tue Jul 25 2017 ohering@suse.de
- Use Group: Development/Languages/OCaml
* Mon Jul 17 2017 ohering@suse.de
- update to 2.18.5
  See included CHANGES for details
* Mon Jul 17 2017 ohering@suse.de
- Wrap specfile conditionals to fix quilt setup
* Mon Jul 17 2017 ohering@suse.de
- Remove autodeps for pre openSUSE 12.1 releases
* Wed May 31 2017 zaitor@opensuse.org
- Change conditional to only apply gtksourceview18-devel
  BuildRequires for SLE 11 and openSUSE 11.4 and older versions of
  openSUSE.
* Tue Nov 10 2015 ohering@suse.de
- Add hardcoded Provides for pre 12.1 repos
* Tue Jun 23 2015 ohering@suse.de
- update to 2.18.3
* Thu Oct 23 2014 ohering@suse.de
- BuildRequire ocaml-rpm-macros
* Sat Sep 27 2014 peter.trommler@ohm-hochschule.de
- update to 2.18.2
  * Revert old commit which broke notify signals
  * Quote $(FLINSTALLDIR) in Makefile (cf PR#1342)
  * Update applications/browser for 4.02
  * Make Float_val an alias for Double_val, since it was used
    wrongly anyway (Felix Ruess)
  * Make GObj.misc_ops#add_accelerator polymorphic in the widget of
    the signal (Erkki Seppala)
  * Use properties in GtkAdjustment, rather than direct accessors
  * fix GtkTree.IconView.get_path_at_pos (Thomas Leonard)
  * add gtksourceview2 to windows binaries
  * prepare release
  * update applications for 4.01
  * various fixes in windows port
  * add some GTK enumerations and update stock icon list
  * add properties GtkTreeView.enable_{tree,grid}_lines
  * add properties GtkEntry.{primary,secondary}_icon_{stock,name,pixbuf},
    see examples/entry2.ml for usage
  * add tags in GtkMovementStep
  * fix compatibility with ocaml 4.01 (?lab for non-optional arguments)
  * add handling of new modifiers
  * detect findlib during configuration
  * support DESTDIR with findlib-install
  * indicate that only old-install supports DESTDIR
  * have old-install copy the META file too
  * cleanup the two phases of findlib-install
  * update Windows port, compiles fine on mingw with
    ./configure --disable-gtktest
  * lablgtk2 script does not load extra libraries by default
    (use flag -all to load all extensions)
  * generate correct lablgtk2 script for findlib.
  * add old-uninstall target.
  * support threaded toplevel with Quartz backend, using gtkThTop.ml
    (runs the toplevel loop in another thread)
  * remove GtkThInit from META (not portable)
  * avoid busy waiting by using g_main_context_set_poll_func to
    make polling non-blocking.
    busy waiting is still needed for VM threads, and can be activated
    by setting the environment variable LABLGTK_BUSY_WAIT.
  * update applications/browser for OCaml 4.00
  * update applications/camlirc to use GText instead of GBroken.text
  * improvements to GtkSourceView2.
  * add cast and assignation functions to GText.nocopy_iter.
  * add Gtk 2.10 missing key modifiers.
  * can still install using old-install.
  * add a high-level API to create keyboard shortcuts.
  * add several #as_foo methods: entry, notebook, range
  * new signals for notebook: select_page, reorder_tab,
    change_current_page, move_focus_out, page_{added,removed,reordered}
  * add gtk_container_child_{set,get}_property
  * add gtk_notebook_{set,get}_tab_reorderable
  * add gtk_signal_new which can be used to create custom keyboard shortcuts
  * add g_signal_list and g_signal_query
  * add functions to connect to notify::foo signals which indicate when an
    object property changes
  * add foo#connect#notify_bar methods to add callbacks on changes of
    the "bar" property of the object "foo".
  * use findlib to install (see README for the list of installed packages)
  * merge GtkSourceView2 additions by Pierre-Marie Pedrot
  * add Make_Val_option to wrappers.h
  * add gtk_accelerator_name/get_label (for Pierre Boutillier)
  * add gtk_accel_map_foreach/change_entry (ibid)
  * add gdk_window_clear_area (for DDR)
  * make gtk_tree_view_get_visible_range version dependent (Thomas Ripoche)
* Mon Jun  3 2013 ohering@suse.de
- Recompress with xz
* Wed Jan 16 2013 ohering@suse.de
- disable also /usr/lib/rpm/find-debuginfo.sh
* Mon Jan 14 2013 ohering@suse.de
- disable strip, it destroys bytecode binaries
* Wed Jan  2 2013 ohering@suse.de
- update specfile to handle disabled do_opt variable
* Mon Nov 12 2012 ohering@suse.de
- BR gtksourceview2-devel in 12.1 and later
* Mon Nov 12 2012 ohering@suse.de
- remove gtksourceview-devel from BuilrRequires, configure does
  not check for version 3
- require gtksourceview18-devel in devel subpackage
* Sat Nov 10 2012 peter.trommler@ohm-hochschule.de
- BR gtksourceview2-devel to provide lablgtksourceview2
* Mon Sep 17 2012 ohering@suse.de
- rename package lablgtk2 to ocaml-lablgtk2
* Fri Jun 17 2011 ampsaltis@gmail.com
- Use ocaml-camlp4-devel instead of camlp4 in BuildRequires
* Wed May 25 2011 idonmez@novell.com
- Ignore GtkSourceView_types and GtkSourceView2_types symbols
* Mon May  2 2011 jslaby@suse.de
- install also .so dlls
- require some gtk libs in the devel package to be able to
  build against the libs
* Wed Nov 10 2010 mhopf@novell.com
- Add additional build dependencies (bnc #413806)
* Thu Oct  7 2010 aj@suse.de
- Update to 2.14.2:
  * Fix incompatibility with ocaml 3.12.
  * Fixes for newer gtk/glib versions.
- Rename rpmlintrc to make name unique.
* Tue Dec  8 2009 mhopf@novell.com
- Configure with --with-gnomecanvas (bnc #560703)
* Wed Feb 25 2009 seife@suse.de
- update to version 2.12.0
  - please see the changelog for details
* Thu Feb 19 2009 radomir.cernoch@gmail.com
- 'make' changed to 'make world' to build additional libraries
- 'configure' changed to '%%configure'
* Mon Apr 21 2008 seife@suse.de
- update to version 2.10.1
  - fix wrong type in GContainer.mli (could not compile with 3.10.2)
  - revert to setting LC_NUMERIC to C (ocaml still uses strtod)
  - Fix Val_GType/GType_val (use Val_addr/Addr_val)
  - add ui_manager#as_ui_manager
  - Fix examples.
* Tue Jan 29 2008 seife@suse.de
- update to version 2.10.0
  - uses features of newer Gtk versions
  - some small bugfixes
* Wed Nov  7 2007 ro@suse.de
- added rpmlintrc
* Fri Jun 15 2007 ro@suse.de
- added rsvg bindings
- handle ppc64 like s390 (no ocamlopt)
* Tue Jun  5 2007 ro@suse.de
- added ocamlp4 to buildreq
- silence a compiler warning
* Thu May 24 2007 ro@suse.de
- branch off devel package
* Wed Sep 20 2006 seife@suse.de
- initial submission (cloned specfile from lablgtk)
